==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/SharedStoreColocatedHAPolicy.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import org.wildfly.swarm.config.runtime.Subresource;
import org.wildfly.swarm.config.messaging_activemq.server.ha_policy.shared_store_colocated.MasterConfiguration;
import org.wildfly.swarm.config.messaging_activemq.server.ha_policy.shared_store_colocated.SlaveConfiguration;
/**
 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
 */
@ResourceType("ha-policy")
@Implicit
public class SharedStoreColocatedHAPolicy<T extends SharedStoreColocatedHAPolicy> {

	private String key;
	private Integer backupPortOffset;
	private Integer backupRequestRetries;
	private Long backupRequestRetryInterval;
	private Integer maxBackups;
	private Boolean requestBackup;
	private MasterConfiguration masterConfiguration;
	private SlaveConfiguration slaveConfiguration;

	public SharedStoreColocatedHAPolicy() {
		this.key = "shared-store-colocated";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The offset to use for the Connectors and Acceptors when creating a new backup server.
	 */
	@ModelNodeBinding(detypedName = "backup-port-offset")
	public Integer backupPortOffset() {
		return this.backupPortOffset;
	}

	/**
	 * The offset to use for the Connectors and Acceptors when creating a new backup server.
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy backupPortOffset(Integer value) {
		this.backupPortOffset = value;
		return (SharedStoreColocatedHAPolicy) this;
	}

	/**
	 * How many times the live server will try to request a backup, -1 means for ever.
	 */
	@ModelNodeBinding(detypedName = "backup-request-retries")
	public Integer backupRequestRetries() {
		return this.backupRequestRetries;
	}

	/**
	 * How many times the live server will try to request a backup, -1 means for ever.
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy backupRequestRetries(Integer value) {
		this.backupRequestRetries = value;
		return (SharedStoreColocatedHAPolicy) this;
	}

	/**
	 * How long (in ms) to wait for retries between attempts to request a backup server.
	 */
	@ModelNodeBinding(detypedName = "backup-request-retry-interval")
	public Long backupRequestRetryInterval() {
		return this.backupRequestRetryInterval;
	}

	/**
	 * How long (in ms) to wait for retries between attempts to request a backup server.
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy backupRequestRetryInterval(Long value) {
		this.backupRequestRetryInterval = value;
		return (SharedStoreColocatedHAPolicy) this;
	}

	/**
	 * Whether or not this live server will accept backup requests from other live servers.
	 */
	@ModelNodeBinding(detypedName = "max-backups")
	public Integer maxBackups() {
		return this.maxBackups;
	}

	/**
	 * Whether or not this live server will accept backup requests from other live servers.
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy maxBackups(Integer value) {
		this.maxBackups = value;
		return (SharedStoreColocatedHAPolicy) this;
	}

	/**
	 * If true then the server will request a backup on another node.
	 */
	@ModelNodeBinding(detypedName = "request-backup")
	public Boolean requestBackup() {
		return this.requestBackup;
	}

	/**
	 * If true then the server will request a backup on another node.
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy requestBackup(Boolean value) {
		this.requestBackup = value;
		return (SharedStoreColocatedHAPolicy) this;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@Subresource
	public MasterConfiguration masterConfiguration() {
		return this.masterConfiguration;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy masterConfiguration(
			MasterConfiguration value) {
		this.masterConfiguration = value;
		return (SharedStoreColocatedHAPolicy) this;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@Subresource
	public SlaveConfiguration slaveConfiguration() {
		return this.slaveConfiguration;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@SuppressWarnings("unchecked")
	public SharedStoreColocatedHAPolicy slaveConfiguration(
			SlaveConfiguration value) {
		this.slaveConfiguration = value;
		return (SharedStoreColocatedHAPolicy) this;
	}
}

==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/SharedStoreColocatedHAPolicy.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import org.wildfly.swarm.config.runtime.Subresource;
import org.wildfly.swarm.config.messaging_activemq.server.ha_policy.shared_store_colocated.MasterConfiguration;
import org.wildfly.swarm.config.messaging_activemq.server.ha_policy.shared_store_colocated.SlaveConfiguration;
/**
 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
 */
@ResourceType("ha-policy")
@Implicit
public class SharedStoreColocatedHAPolicy<T extends SharedStoreColocatedHAPolicy> {

	private String key;
	private Integer backupPortOffset;
	private Integer backupRequestRetries;
	private Long backupRequestRetryInterval;
	private Integer maxBackups;
	private Boolean requestBackup;
	private MasterConfiguration masterConfiguration;
	private SlaveConfiguration slaveConfiguration;

	public SharedStoreColocatedHAPolicy() {
		this.key = "shared-store-colocated";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The offset to use for the Connectors and Acceptors when creating a new backup server.
	 */
	@ModelNodeBinding(detypedName = "backup-port-offset")
	public Integer backupPortOffset() {
		return this.backupPortOffset;
	}

	/**
	 * The offset to use for the Connectors and Acceptors when creating a new backup server.
	 */
	@SuppressWarnings("unchecked")
	public T backupPortOffset(Integer value) {
		this.backupPortOffset = value;
		return (T) this;
	}

	/**
	 * How many times the live server will try to request a backup, -1 means for ever.
	 */
	@ModelNodeBinding(detypedName = "backup-request-retries")
	public Integer backupRequestRetries() {
		return this.backupRequestRetries;
	}

	/**
	 * How many times the live server will try to request a backup, -1 means for ever.
	 */
	@SuppressWarnings("unchecked")
	public T backupRequestRetries(Integer value) {
		this.backupRequestRetries = value;
		return (T) this;
	}

	/**
	 * How long (in ms) to wait for retries between attempts to request a backup server.
	 */
	@ModelNodeBinding(detypedName = "backup-request-retry-interval")
	public Long backupRequestRetryInterval() {
		return this.backupRequestRetryInterval;
	}

	/**
	 * How long (in ms) to wait for retries between attempts to request a backup server.
	 */
	@SuppressWarnings("unchecked")
	public T backupRequestRetryInterval(Long value) {
		this.backupRequestRetryInterval = value;
		return (T) this;
	}

	/**
	 * Whether or not this live server will accept backup requests from other live servers.
	 */
	@ModelNodeBinding(detypedName = "max-backups")
	public Integer maxBackups() {
		return this.maxBackups;
	}

	/**
	 * Whether or not this live server will accept backup requests from other live servers.
	 */
	@SuppressWarnings("unchecked")
	public T maxBackups(Integer value) {
		this.maxBackups = value;
		return (T) this;
	}

	/**
	 * If true then the server will request a backup on another node.
	 */
	@ModelNodeBinding(detypedName = "request-backup")
	public Boolean requestBackup() {
		return this.requestBackup;
	}

	/**
	 * If true then the server will request a backup on another node.
	 */
	@SuppressWarnings("unchecked")
	public T requestBackup(Boolean value) {
		this.requestBackup = value;
		return (T) this;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@Subresource
	public MasterConfiguration masterConfiguration() {
		return this.masterConfiguration;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@SuppressWarnings("unchecked")
	public T masterConfiguration(MasterConfiguration value) {
		this.masterConfiguration = value;
		return (T) this;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@Subresource
	public SlaveConfiguration slaveConfiguration() {
		return this.slaveConfiguration;
	}

	/**
	 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
	 */
	@SuppressWarnings("unchecked")
	public T slaveConfiguration(SlaveConfiguration value) {
		this.slaveConfiguration = value;
		return (T) this;
	}
}
